%global api_ver %%(echo %{version} | cut -d. -f1-2)

Summary:        A modern programming language for GNOME
Name:           vala
Version:        0.56.9
Release:        3%{?dist}
License:        LGPLv2+ and BSD
URL:            https://wiki.gnome.org/Projects/Vala
Source0:        https://download.gnome.org/sources/vala/%{api_ver}/vala-%{version}.tar.xz

BuildRequires:  bison flex gobject-introspection-devel graphviz-devel libxslt make
BuildRequires:  pkgconfig(gobject-2.0) dbus-x11

Requires: libvala = %{version}-%{release} gobject-introspection-devel
Provides: vala(api) = %{api_ver}

%description
Vala is a new programming language that aims to bring modern programming language features to GNOME
developers without imposing any additional runtime requirements and without using a different ABI compared to
applications and libraries written in C.

valac, the Vala compiler, is a self-hosting compiler that translates Vala source code into C source and header files.
It uses the GObject type system to create classes and interfaces declared in the Vala source code. It's also planned
to generate GIDL files when gobject-introspection is ready.

The syntax of Vala is similar to C#, modified to better fit the GObject type system.

%package -n     libvala
Summary:        Vala compiler library

%description -n libvala
Vala is a new programming language that aims to bring modern programming language features to GNOME
developers without imposing any additional runtime requirements and without using a different ABI compared to
applications and libraries written in C.

This package contains the shared libvala library.

%package -n     libvala-devel
Summary:        Development files for libvala
Requires:       libvala = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n libvala-devel
Vala is a new programming language that aims to bring modern programming language features to GNOME
developers without imposing any additional runtime requirements and without using a different ABI compared to
applications and libraries written in C.

This package contains development files for libvala. This is not necessary for using the %{name} compiler.

%package -n     valadoc
Summary:        Vala documentation generator
Requires:       %{name} = %{version}-%{release}

%description -n valadoc
Valadoc is a documentation generator for generating API documentation from Vala source code.


%package -n     valadoc-devel
Summary:        Development files for valadoc
Requires:       valadoc = %{version}-%{release}

%description -n valadoc-devel
Valadoc is a documentation generator for generating API documentation from Vala source code.

The valadoc-devel package contains libraries and header files for developing applications that use valadoc.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%configure
sed -i 's|/lib /usr/lib|/lib /usr/lib /lib64 /usr/lib64|' libtool
%make_build

%install
%make_install

mv %{buildroot}%{_bindir}/vala-gen-introspect-%{api_ver}{,-`uname -m`}
echo -e '#!/bin/sh\nexec %{_bindir}/vala-gen-introspect-%{api_ver}-`uname -m` "$@"' > \
  %{buildroot}%{_bindir}/vala-gen-introspect-%{api_ver}
  chmod +x %{buildroot}%{_bindir}/vala-gen-introspect-%{api_ver}

find %{buildroot} -name '*.la' -exec rm -f {} ';'

# do not support html
rm -rf %{buildroot}%{_datadir}/devhelp/books

%check
%make_build check

%files
%license COPYING
%{_bindir}/vala
%{_bindir}/vala-%{api_ver}
%{_bindir}/valac
%{_bindir}/valac-%{api_ver}
%{_bindir}/vala-gen-introspect
%{_bindir}/vala-gen-introspect-%{api_ver}*
%{_bindir}/vapigen
%{_bindir}/vapigen-%{api_ver}
%{_libdir}/pkgconfig/vapigen*.pc
%{_libdir}/vala-%{api_ver}/
%{_datadir}/aclocal/vala.m4
%{_datadir}/aclocal/vapigen.m4
%{_datadir}/vala/
%{_datadir}/vala-%{api_ver}/
%{_mandir}/man1/valac.1*
%{_mandir}/man1/valac-%{api_ver}.1*
%{_mandir}/man1/vala-gen-introspect.1*
%{_mandir}/man1/vala-gen-introspect-%{api_ver}.1*
%{_mandir}/man1/vapigen.1*
%{_mandir}/man1/vapigen-%{api_ver}.1*

%files -n libvala
%license COPYING
%{_libdir}/libvala-%{api_ver}.so.*

%files -n libvala-devel
%{_includedir}/vala-%{api_ver}
%{_libdir}/libvala-%{api_ver}.so
%{_libdir}/pkgconfig/libvala-%{api_ver}.pc

%files -n valadoc
%{_bindir}/valadoc
%{_bindir}/valadoc-%{api_ver}
%{_libdir}/libvaladoc-%{api_ver}.so.0*
%{_libdir}/valadoc-%{api_ver}/
%{_datadir}/valadoc-%{api_ver}/
%{_mandir}/man1/valadoc-%{api_ver}.1*
%{_mandir}/man1/valadoc.1*

%files -n valadoc-devel
%{_includedir}/valadoc-%{api_ver}/
%{_libdir}/libvaladoc-%{api_ver}.so
%{_libdir}/pkgconfig/valadoc-%{api_ver}.pc

%changelog
* Wed Jan 10 2024 Rebuild Robot <rebot@opencloudos.org> - 0.56.9-3
- Rebuilt for graphviz

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.56.9-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Jul 28 2023 Shuo Wang <abushwang@tencent.com> - 0.56.9-1
- update to 0.56.9

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.55.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.55.3-2
- Rebuilt for OpenCloudOS Stream 23

* Tue Dec 6 2022 Shuo Wang <abushwang@tencent.com> - 0.55.3-1
- initial build
